--[[ 
	CircleHUD
	by Chrome67
	available @ Curse.com and WoWInterface.com
	(fan updated and mod'ed version of AlarmHUDpie by lab1702)

	==Change Log==
	- v1.0 - Initial release
	- v1.1 - minor visual enhancement


]]
local Graph = LibStub:GetLibrary("LibGraph-2.0")


local function CircleHUD_ShortNumber(h)
  if h > 999999 then
    return format("%.1fm", h / 1000000)
  elseif h > 9999 then
    return format("%.1fk", h / 1000)
  else
    return format("%d", h)
  end
end

local pieRadius = 50
local pieOffsetX = UIParent:GetWidth() / 7
local pieOffsetY = UIParent:GetHeight() / 7
local ShadowpieOffsetX = UIParent:GetWidth() / 7
local ShadowpieOffsetY = UIParent:GetHeight() / 7

local targetPieShadow = Graph:CreateGraphPieChart("CircleHUDtargetShadow", UIParent, "CENTER", "CENTER", ShadowpieOffsetX, -ShadowpieOffsetY, pieRadius * 1.4, pieRadius * 1.4)
targetPieShadow:SetFrameLevel(targetPieShadow:GetFrameLevel() - 1)

targetPieShadow:RegisterEvent("PLAYER_TARGET_CHANGED")

targetPieShadow:SetScript("OnEvent",
  function(frame, event, unit, ...)
    if unit == "target" or event == "PLAYER_TARGET_CHANGED" then
		frame:ResetPie()
		if UnitExists("target") then
			frame:CompletePie({0, 0, 0})
		end
	end
  end
)

local targetPowerPie = Graph:CreateGraphPieChart("CircleHUDTargetPower", UIParent, "CENTER", "CENTER", pieOffsetX, -pieOffsetY, pieRadius * 1.3, pieRadius * 1.3)

targetPowerPie:RegisterEvent("PLAYER_TARGET_CHANGED")
targetPowerPie:RegisterEvent("UNIT_DISPLAYPOWER")
targetPowerPie:RegisterEvent("UNIT_POWER")
targetPowerPie:RegisterEvent("UNIT_MAXPOWER")

targetPowerPie:SetScript("OnEvent",
  function(frame, event, unit, ...)
    if unit == "target" or event == "PLAYER_TARGET_CHANGED" then
      frame:ResetPie()

      if UnitExists("target") then
        local p = (100 * UnitPower("target")) / UnitPowerMax("target")
        local col = PowerBarColor[UnitPowerType("target")]

        if p >= 100 then
          frame:CompletePie({col.r, col.g, col.b})
        else
          frame:AddPie(p, {col.r, col.g, col.b})
          frame:CompletePie({0, 0, 0})
        end
      end
    end
  end
)


local targetPie = Graph:CreateGraphPieChart("CircleHUDTarget", UIParent, "CENTER", "CENTER", pieOffsetX, -pieOffsetY, pieRadius, pieRadius)
targetPie:SetFrameLevel(targetPie:GetFrameLevel() + 1)

local targetNumber = UIParent:CreateFontString("CircleHUDTargetNumber", "LOW", "GameFontNormalHuge")
targetNumber:SetPoint("LEFT", targetPowerPie, "RIGHT", 5, 0)

local targetName = UIParent:CreateFontString("CircleHUDTargetName", "LOW", "GameFontNormal")
targetName:SetPoint("BOTTOM", targetPowerPie, "TOP", 0, 5)

local targetPercent = UIParent:CreateFontString("CircleHUDTargetPercent", "LOW", "GameFontNormal")
targetPercent:SetPoint("TOP", targetPowerPie, "BOTTOM", 0, -5)

local targetIcon = UIParent:CreateTexture("CircleHUDTargetIcon", "OVERLAY")
targetIcon:SetHeight(pieRadius * 0.75)
targetIcon:SetWidth(pieRadius * 0.75)
targetIcon:SetTexture("Interface\\TargetingFrame\\UI-RaidTargetingIcons")
targetIcon:SetPoint("RIGHT", targetPowerPie, "LEFT", -5, 0)
targetIcon:Hide()

targetPie:RegisterEvent("PLAYER_TARGET_CHANGED")
targetPie:RegisterEvent("RAID_TARGET_UPDATE")
targetPie:RegisterEvent("UNIT_HEALTH")
targetPie:RegisterEvent("UNIT_MAXHEALTH")

targetPie:SetScript("OnEvent",
  function(frame, event, unit, ...)
    if unit == "target" or event == "PLAYER_TARGET_CHANGED" or event == "RAID_TARGET_UPDATE" then
      frame:ResetPie()

      if UnitExists("target") then
        local p = (100 * UnitHealth("target")) / UnitHealthMax("target")
        local _, c = UnitClass("target")

        if not c then
          c = "WARRIOR"
        end

        local col = RAID_CLASS_COLORS[c]
        local idx = GetRaidTargetIndex("target")

        if idx then
          SetRaidTargetIconTexture(targetIcon, idx)
          targetIcon:Show()
        else
          targetIcon:Hide()
        end

        if event == "PLAYER_TARGET_CHANGED" then
          targetName:SetText(UnitName("target"))
          targetName:SetTextColor(col.r, col.g, col.b)
        end

        targetNumber:SetText(CircleHUD_ShortNumber(UnitHealth("target")))
        targetPercent:SetFormattedText("%d%%", (100 * UnitHealth("target")) / UnitHealthMax("target"))

        if p >= 100 then
          frame:AddPie(35, {0.7, 0.2, 0.2})
          frame:CompletePie({0.6, 0.2, 0.2})
        elseif p > 35 then
          frame:AddPie(35, {0.7, 0.2, 0.2})
          frame:AddPie(p - 35, {0.6, 0.2, 0.2})
          frame:CompletePie({0, 0, 0})
        else
          frame:AddPie(p, {1, 0.2, 0.2})
          frame:CompletePie({0, 0, 0})
        end
      else
        targetName:SetText("")
        targetNumber:SetText("")
        targetPercent:SetText("")
        targetIcon:Hide()
      end
    end
  end
)

local healthPieShadow = Graph:CreateGraphPieChart("CircleHUDHealthShadow", UIParent, "CENTER", "CENTER", -ShadowpieOffsetX, -ShadowpieOffsetY, pieRadius * 1.4, pieRadius * 1.4)
healthPieShadow:SetFrameLevel(healthPieShadow:GetFrameLevel() - 1)

healthPieShadow:RegisterEvent("PLAYER_ENTERING_WORLD")

healthPieShadow:SetScript("OnEvent",
  function(frame, event, unit, ...)
    if unit == "player" or event == "PLAYER_ENTERING_WORLD" then
		frame:ResetPie()
		if UnitExists("player") then
			frame:CompletePie({0, 0, 0})
		end
	end
  end
)


local powerPie = Graph:CreateGraphPieChart("CircleHUDPower", UIParent, "CENTER", "CENTER", -pieOffsetX, -pieOffsetY, pieRadius * 1.3, pieRadius * 1.3)

local powerValue = UIParent:CreateFontString("CircleHUDPowerValue", "LOW", "GameFontNormal")
powerValue:SetPoint("BOTTOM", powerPie, "LEFT", -15, 0)

local powerMaxValue = UIParent:CreateFontString("CircleHUDPowerMaxValue", "LOW", "GameFontNormalSmall")
powerMaxValue:SetPoint("TOP", powerPie, "LEFT", -15, 0)

powerPie:RegisterEvent("PLAYER_ENTERING_WORLD")
powerPie:RegisterEvent("UNIT_DISPLAYPOWER")
powerPie:RegisterEvent("UNIT_POWER")
powerPie:RegisterEvent("UNIT_MAXPOWER")
--[[
if select(2, UnitClass("player")) == "DEATHKNIGHT" then
  powerPie:RegisterEvent("UNIT_RUNIC_POWER")
  powerPie:RegisterEvent("UNIT_MAXRUNIC_POWER")
else
	if select(2, UnitClass("player")) == "WARRIOR" then
		powerPie:RegisterEvent("UNIT_RAGE")
		powerPie:RegisterEvent("UNIT_MAXRAGE")
	else
		if select(2, UnitClass("player")) == "ROGUE" then
			powerPie:RegisterEvent("UNIT_ENERGY")
			powerPie:RegisterEvent("UNIT_MAXENERGY")
		else
			if select(2, UnitClass("player")) == "HUNTER" then
			powerPie:RegisterEvent("UNIT_FOCUS")
			powerPie:RegisterEvent("UNIT_MAXFOCUS")
			else
				powerPie:RegisterEvent("UNIT_MANA")
				powerPie:RegisterEvent("UNIT_MAXMANA")
  		end
  	end
end
]]


powerPie:SetScript("OnEvent",
  function(frame, event, unit, ...)
    if unit == "player" or event == "PLAYER_ENTERING_WORLD" then
      frame:ResetPie()

      if UnitExists("player") then
        local p = (100 * UnitPower("player")) / UnitPowerMax("player")
        local c = PowerBarColor[UnitPowerType("player")]

        powerMaxValue:SetText(UnitPowerMax("player"))
        powerValue:SetText(UnitPower("player"))

        if p >= 100 then
          frame:CompletePie({c.r, c.g, c.b})
        else
          frame:AddPie(p, {c.r, c.g, c.b})
          frame:CompletePie({1, 1, 1})
        end
      else
        powerMaxValue:SetText("")
        powerValue:SetText("")
      end
    end
  end
)

local healthPie = Graph:CreateGraphPieChart("CircleHUDHealth", UIParent, "CENTER", "CENTER", -pieOffsetX, -pieOffsetY, pieRadius, pieRadius)
healthPie:SetFrameLevel(healthPie:GetFrameLevel() + 1)

local healthValue = UIParent:CreateFontString("CircleHUDHealthValue", "LOW", "GameFontNormal")
healthValue:SetPoint("BOTTOM", healthPie, "RIGHT", 20, 0)

local healthMaxValue = UIParent:CreateFontString("CircleHUDHealthMaxValue", "LOW", "GameFontNormalSmall")
healthMaxValue:SetPoint("TOP", healthPie, "RIGHT", 20, 0)

healthPie:RegisterEvent("PLAYER_ENTERING_WORLD")
healthPie:RegisterEvent("UNIT_HEALTH")
healthPie:RegisterEvent("UNIT_MAXHEALTH")

healthPie:SetScript("OnEvent",
  function(frame, event, unit, ...)
    if unit == "player" or event == "PLAYER_ENTERING_WORLD" then
      frame:ResetPie()

      if UnitExists("player") then
        local p = (100 * UnitHealth("player")) / UnitHealthMax("player")

        healthMaxValue:SetText(UnitHealthMax("player"))
        healthValue:SetText(UnitHealth("player"))

        if p >= 100 then
          frame:CompletePie({0, 1, 0})
        else
          frame:AddPie(p, {0, 1, 0})
          frame:CompletePie({0, 0, 0})
        end
      else
        healthMaxValue:SetText("")
        healthValue:SetText("")
      end
    end
  end
)


